Package: rprojroot
Title: Finding Files in Project Subdirectories
Version: 2.1.1
Authors@R: 
    person(given = "Kirill",
           family = "M\u00fcller",
           role = c("aut", "cre"),
           email = "kirill@cynkra.com",
           comment = c(ORCID = "0000-0002-1416-3412"))
Description: Robust, reliable and flexible paths to files below
    a project root. The 'root' of a project is defined as a directory that
    matches a certain criterion, e.g., it contains a certain regular file.
License: MIT + file LICENSE
URL: https://rprojroot.r-lib.org/, https://github.com/r-lib/rprojroot
BugReports: https://github.com/r-lib/rprojroot/issues
Depends: R (>= 3.0.0)
Suggests: covr, knitr, lifecycle, rlang, rmarkdown, testthat (>=
        3.2.0), withr
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.2.9000
Config/autostyle/scope: line_breaks
Config/autostyle/strict: true
Config/Needs/website: tidyverse/tidytemplate
NeedsCompilation: no
Packaged: 2025-08-26 15:22:42 UTC; kirill
Author: Kirill Müller [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1416-3412>)
Maintainer: Kirill Müller <kirill@cynkra.com>
Repository: CRAN
Date/Publication: 2025-08-26 16:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 09:05:43 UTC; unix
