Package: hierarchy
Title: What the Package Does (one line, title case)
Version: 0.0-0
Authors@R: as.person("Kirill Müller <krlmlr+r@mailbox.org> [aut, cre]")
Description: What the package* does.
Depends: R (>= 3.2.0)
License: GPL-3
LazyData: true
Encoding: UTF-8
