#' @rdname find_root_file
#' @export
find_rstudio_root_file <- is_rstudio_project$find_file

#' @rdname find_root_file
#' @export
find_package_root_file <- is_r_package$find_file

#' @rdname find_root_file
#' @export
find_remake_root_file <- is_remake_project$find_file

#' @rdname find_root_file
#' @export
find_testthat_root_file <- is_testthat$find_file
